package weimob

import (
	"encoding/json"
	"errors"
)

func (w *WeimobConfig) OrderDetial(accesstoken, orderNo string) (res *WeimodOrderDetialRes, err error) {
	if len(orderNo) <= 0 {
		err = errors.New("订单号错误")
		return
	}
	url := w.ApiUrl + "api/1_0/ec/order/queryOrderDetail?accesstoken=" + accesstoken
	body, err := json.Marshal(map[string]string{"orderNo": orderNo})
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

//微店取消订单
func (w *WeimobConfig) WeimobCancelOrder(accesstoken, orderNo, specificCancelReason, cancelReason string, cancelReasonId int) (res string, err error) {
	if len(orderNo) <= 0 {
		err = errors.New("订单号错误")
		return
	}
	deliveryParams := map[string]interface{}{
		"orderNo": orderNo,
	}
	if len(specificCancelReason) > 0 {
		deliveryParams["specificCancelReason"] = specificCancelReason
	}
	if len(cancelReason) > 0 {
		deliveryParams["cancelReason"] = cancelReason
	}
	if cancelReasonId > 0 {
		deliveryParams["cancelReasonId"] = cancelReasonId
	}
	url := w.ApiUrl + "api/1_0/ec/order/cancelOrder?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

//微店发货接口
func (w *WeimobConfig) WeimobLogisticsAddMultiPack(accesstoken string, deliveryParams map[string]interface{}) (res string, err error) {
	url := w.ApiUrl + "api/1_0/ec/order/deliveryOrder?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}
func (w *WeimobConfig) OrderList(accesstoken string, order *WeimodOrderListReq) (res *WeimodOrderListRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/order/queryOrderList?accesstoken=" + accesstoken
	body, err := json.Marshal(order)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}
